<?php

namespace Laravel\Laravel\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Laravel\Laravel\Http\Requests\AddadminRequest;
use Laravel\Laravel\Interfaces\AddadminRepositoryInterface;
use Laravel\Laravel\Models\Addadmin;

/**
 * Resource controller class for addadmin.
 */
class AddadminResourceController extends BaseController
{

    /**
     * Initialize addadmin resource controller.
     *
     * @param type AddadminRepositoryInterface $addadmin
     *
     * @return null
     */
    public function __construct(AddadminRepositoryInterface $addadmin)
    {
        parent::__construct();
        $this->repository = $addadmin;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Laravel\Laravel\Repositories\Criteria\AddadminResourceCriteria::class);
    }

    /**
     * Display a list of addadmin.
     *
     * @return Response
     */
    public function index(AddadminRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Laravel\Laravel\Repositories\Presenter\AddadminPresenter::class)
                ->$function();
        }

        $addadmins = $this->repository->paginate();

        return $this->response->title(trans('laravel::addadmin.names'))
            ->view('laravel::addadmin.index', true)
            ->data(compact('addadmins', 'view'))
            ->output();
    }

    /**
     * Display addadmin.
     *
     * @param Request $request
     * @param Model   $addadmin
     *
     * @return Response
     */
    public function show(AddadminRequest $request, Addadmin $addadmin)
    {

        if ($addadmin->exists) {
            $view = 'laravel::addadmin.show';
        } else {
            $view = 'laravel::addadmin.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('laravel::addadmin.name'))
            ->data(compact('addadmin'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new addadmin.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AddadminRequest $request)
    {

        $addadmin = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('laravel::addadmin.name')) 
            ->view('laravel::addadmin.create', true) 
            ->data(compact('addadmin'))
            ->output();
    }

    /**
     * Create new addadmin.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AddadminRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $addadmin                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('laravel::addadmin.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('laravel/addadmin/' . $addadmin->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/laravel/addadmin'))
                ->redirect();
        }

    }

    /**
     * Show addadmin for editing.
     *
     * @param Request $request
     * @param Model   $addadmin
     *
     * @return Response
     */
    public function edit(AddadminRequest $request, Addadmin $addadmin)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('laravel::addadmin.name'))
            ->view('laravel::addadmin.edit', true)
            ->data(compact('addadmin'))
            ->output();
    }

    /**
     * Update the addadmin.
     *
     * @param Request $request
     * @param Model   $addadmin
     *
     * @return Response
     */
    public function update(AddadminRequest $request, Addadmin $addadmin)
    {
        try {
            $attributes = $request->all();

            $addadmin->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('laravel::addadmin.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('laravel/addadmin/' . $addadmin->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('laravel/addadmin/' . $addadmin->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the addadmin.
     *
     * @param Model   $addadmin
     *
     * @return Response
     */
    public function destroy(AddadminRequest $request, Addadmin $addadmin)
    {
        try {

            $addadmin->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('laravel::addadmin.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('laravel/addadmin/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('laravel/addadmin/' . $addadmin->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple addadmin.
     *
     * @param Model   $addadmin
     *
     * @return Response
     */
    public function delete(AddadminRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('laravel::addadmin.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('laravel/addadmin'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/laravel/addadmin'))
                ->redirect();
        }

    }

    /**
     * Restore deleted addadmins.
     *
     * @param Model   $addadmin
     *
     * @return Response
     */
    public function restore(AddadminRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('laravel::addadmin.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/laravel/addadmin'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/laravel/addadmin/'))
                ->redirect();
        }

    }

}
